/*
 * Lempel-Ziev-Welch lossless data compression algorithm.
 *
 * sitkarev@komitex.ru, 2012 (c)
 *
 */
#ifndef _LZW_H_
#define _LZW_H_

#ifdef __cplusplus
extern "C" {
#endif

/*
 * LZW library return codes.
 */
#define LZW_OK		0
#define LZW_FAIL	1
#define LZW_NOMEM	2
#define LZW_NOSPACE	3
#define LZW_BADCODE	4

#include "lzw_private.h"

/* LZW encoder routines */

struct lzw_encoder;

int lzw_encoder_init(struct lzw_encoder *encoder);

#define lzw_encoder_deinit(encoder) do { } while (0)

int lzw_encode(struct lzw_encoder *encoder, const unsigned char **in, size_t *insz, unsigned char **out, size_t *outsz);

int lzw_end_of_data(struct lzw_encoder *encoder, unsigned char **out, size_t *outsz);

int lzw_reset(struct lzw_encoder *encoder, unsigned char **out, size_t *outsz);

int lzw_complete(struct lzw_encoder *encoder);


/* LZW decoder routines */

struct lzw_decoder;

int lzw_decoder_init(struct lzw_decoder *decoder);

#define lzw_decoder_deinit(decoder) do { } while (0)

int lzw_decode(struct lzw_decoder *decoder, const unsigned char **in, size_t *insz, unsigned char **out, size_t *outsz);

#ifdef __cplusplus
}
#endif

#endif /* _LZW_H_ */

